Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1209)

Unified Diff: chrome/browser/renderer_host/render_widget_host_view_mac.mm

Issue 4815001: Use inner HWND for accelerated rendering on windows (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/renderer_host/render_widget_host_view_mac.mm
===================================================================
--- chrome/browser/renderer_host/render_widget_host_view_mac.mm (revision 67491)
+++ chrome/browser/renderer_host/render_widget_host_view_mac.mm (working copy)
@@ -745,7 +745,7 @@
if (!is_hidden_) {
std::vector<gfx::Rect> rects(copy_rects);
- // Because the findbar might be open, we cannot use scrollRect:by: here. For
+ // Because the findbar might be open, we cannot use scrollRect:by: here. For
// now, simply mark all of scroll rect as dirty.
if (!scroll_rect.IsEmpty())
rects.push_back(scroll_rect);
@@ -1019,8 +1019,8 @@
// Plugins are destroyed on page navigate. The compositor layer on the other
// hand is created on demand and then stays alive until its renderer process
// dies (usually on cross-domain navigation). Instead, only a flag
// |is_gpu_rendering_active()| is flipped when the compositor output should be
// shown/hidden.
// Show/hide the view belonging to the compositor here.
plugin_container_manager_.set_gpu_rendering_active(show_gpu_widget);
@@ -1085,9 +1085,9 @@
void RenderWidgetHostViewMac::GpuRenderingStateDidChange() {
CHECK(BrowserThread::CurrentlyOn(BrowserThread::UI));
- if (GetRenderWidgetHost()->is_gpu_rendering_active()) {
+ if (GetRenderWidgetHost()->is_accelerated_compositing_active()) {
UpdateRootGpuViewVisibility(
- GetRenderWidgetHost()->is_gpu_rendering_active());
+ GetRenderWidgetHost()->is_accelerated_compositing_active());
} else {
needs_gpu_visibility_update_after_repaint_ = true;
}
@@ -1685,7 +1685,8 @@
const gfx::Rect damagedRect([self flipNSRectToRect:dirtyRect]);
- if (renderWidgetHostView_->render_widget_host_->is_gpu_rendering_active()) {
+ if (renderWidgetHostView_->render_widget_host_->
+ is_accelerated_compositing_active()) {
gfx::Rect gpuRect;
gfx::PluginWindowHandle root_handle =
@@ -1019,8 +1019,8 @@
// hand is created on demand and then stays alive until its renderer process
// dies (usually on cross-domain navigation). Instead, only a flag
- // |is_gpu_rendering_active()| is flipped when the compositor output should be
- // shown/hidden.
+ // |is_accelerated_compositing_active()| is flipped when the compositor output
+ // should be shown/hidden.
// Show/hide the view belonging to the compositor here.
plugin_container_manager_.set_gpu_rendering_active(show_gpu_widget);

Powered by Google App Engine
This is Rietveld 408576698